@@ -1,6 +1,6 @@
 <?php
 /* vim: set expandtab tabstop=4 shiftwidth=4 foldmethod=marker: */
-/* @(#) $Header: /sources/phpprintipp/phpprintipp/CupsPrintIPP.php,v 1.8 2006/01/16 22:16:17 harding Exp $
+/* @(#) $Header: /sources/phpprintipp/phpprintipp/CupsPrintIPP.php,v 1.9 2006/01/17 18:13:30 harding Exp $
  *
  * Version: 0.2
  * Class PrintIPP - Send extended IPP requests.
@@ -108,11 +108,6 @@ class CupsPrintIPP extends ExtendedPrintIPP {
         if (self::_sendHttp ($post_values,'/')) {
             
             if(self::_parseServerOutput())
-            /*
-            echo "<pre>";
-                print_r($this->serveroutput->response);
-            echo "</pre>";
-            */
                 self::_parsePrinterAttributes();
             }
                 
@@ -143,6 +138,138 @@ class CupsPrintIPP extends ExtendedPrintIPP {
     return false;   
     }
     // }}}
+    
+    // {{{ cupsAcceptJobs ($printer_uri)
+    public function cupsAcceptJobs($printer_uri) {
+    //The CUPS-Get-Default operation returns the default printer URI and attributes
+     
+        $this->jobs = array_merge($this->jobs,array(""));
+        $this->jobs_uri = array_merge($this->jobs_uri,array(""));
+        $this->parsed = array();
+        unset($this->printer_attributes);
+        
+        if (!isset($this->setup->charset))
+            self::setCharset('us-ascii');
+        
+        if (!isset($this->setup->language))
+            self::setLanguage('en');
+            
+        self::_setOperationId();
+       
+       $this->stringjob = chr(0x01) . chr(0x01) // IPP version 1.1 
+                         . chr(0x40). chr(0x08) // operation:  cups vendor extension: Accept-Jobs
+                         . $this->meta->operation_id // request-id
+                         . chr(0x01) // start operation-attributes | operation-attributes-tag
+                         . $this->meta->charset
+                         . $this->meta->language
+                         . chr(0x45) // uri
+                         . self::_giveMeStringLength('printer-uri')
+                         . 'printer-uri'
+                         . self::_giveMeStringLength($printer_uri)
+                         . $printer_uri
+                         . chr(0x03); // end operations attribute
+                        
+        $this->output = $this->stringjob;
+        
+        self::_putDebug("Request: ".$this->output);
+        
+        $post_values = array( "Content-Type" => "application/ipp",
+                              "Data" => $this->output);
+            
+        if (self::_sendHttp ($post_values,'/admin/')) {
+            
+            if(self::_parseServerOutput())
+                self::_parseAttributes();
+            }
+                
+        if (isset($this->serveroutput) && isset($this->serveroutput->status)) {
+            
+            $this->status = array_merge($this->status,array($this->serveroutput->status));
+            if ($this->serveroutput->status == "successfull-ok")
+                self::_errorLog("getting defaults: ".$this->serveroutput->status,3);
+            else
+                self::_errorLog("getting defaults: ".$this->serveroutput->status,1);
+            
+            return $this->serveroutput->status; 
+            
+        } else {
+            $this->status = array_merge($this->status,array("OPERATION FAILED"));
+            self::_errorLog("getting defaults : OPERATION FAILED",1);
+            }
+    return false;   
+    }
+    // }}}
+
+    // {{{ cupsRejectJobs ($printer_uri,$printer_state_message=false)
+    public function cupsRejectJobs($printer_uri,$printer_state_message) {
+    //The CUPS-Get-Default operation returns the default printer URI and attributes
+     
+        $this->jobs = array_merge($this->jobs,array(""));
+        $this->jobs_uri = array_merge($this->jobs_uri,array(""));
+        $this->parsed = array();
+        unset($this->attributes);
+        
+        if (!isset($this->setup->charset))
+            self::setCharset('us-ascii');
+        
+        if (!isset($this->setup->language))
+            self::setLanguage('en');
+            
+        self::_setOperationId();
+        
+        $message = "";
+        if ($printer_state_message)
+            $message = chr(0x04) // start printer-attributes
+                     . chr(0x41) // textWithoutLanguage
+                     . self::_giveMeStringLength("printer-state-message")
+                     . "printer-state-message"
+                     . self::_giveMeStringLength($printer_state_message)
+                     . $printer_state_message;
+
+       $this->stringjob = chr(0x01) . chr(0x01) // IPP version 1.1 
+                         . chr(0x40). chr(0x09) // operation:  cups vendor extension: Reject-Jobs
+                         . $this->meta->operation_id // request-id
+                         . chr(0x01) // start operation-attributes | operation-attributes-tag
+                         . $this->meta->charset
+                         . $this->meta->language
+                         . chr(0x45) // uri
+                         . self::_giveMeStringLength('printer-uri')
+                         . 'printer-uri'
+                         . self::_giveMeStringLength($printer_uri)
+                         . $printer_uri
+                         . $message
+                         . chr(0x03); // end operations attribute
+                        
+        $this->output = $this->stringjob;
+        
+        self::_putDebug("Request: ".$this->output);
+        
+        $post_values = array( "Content-Type" => "application/ipp",
+                              "Data" => $this->output);
+            
+        if (self::_sendHttp ($post_values,'/admin/')) {
+            
+            if(self::_parseServerOutput())
+                self::_parseAttributes();
+            }
+                
+        if (isset($this->serveroutput) && isset($this->serveroutput->status)) {
+            
+            $this->status = array_merge($this->status,array($this->serveroutput->status));
+            if ($this->serveroutput->status == "successfull-ok")
+                self::_errorLog("getting defaults: ".$this->serveroutput->status,3);
+            else
+                self::_errorLog("getting defaults: ".$this->serveroutput->status,1);
+            
+            return $this->serveroutput->status; 
+            
+        } else {
+            $this->status = array_merge($this->status,array("OPERATION FAILED"));
+            self::_errorLog("getting defaults : OPERATION FAILED",1);
+            }
+    return false;   
+    }
+    // }}}
 
     // {{{ getPrinters()
     public function getPrinters($printer_location=false,$printer_info=false,$attributes=array()) {
@@ -269,14 +396,90 @@ class CupsPrintIPP extends ExtendedPrintIPP {
     // {{{ _initTags ()
     protected function _initTags () {
         
+        // override parent with specific cups attributes
+        
         $operation_tags = array (); 
         $this->operation_tags = array_merge ($this->operation_tags, $operation_tags);
-        
-        $job_tags = array ( "job-billing" => array("tag" => "textWithoutLanguage") );
+               
+        $job_tags = array ( "job-billing" => array("tag" => "textWithoutLanguage"),
+                            "blackplot" => array("tag" => "boolean"),
+                            "brightness" => array("tag" => "integer"),
+                            "columns" => array("tag" => "integer"),
+                            "cpi" => array("tag" => "enum"),
+                            "fitplot" => array("tag" => "boolean"),
+                            "gamma" => array("tag" => "integer"),
+                            "hue" => array("tag" => "integer"),
+                            "lpi" => array("tag" => "enum"),
+                            "mirror" => array("tag","boolean"),
+                            "natural-scaling" => array("tag" => "integer"),
+                            "number-up-layout" => array("tag" => "keyword"),
+                            "page-border" => array("tag" => "keyword"),
+                            "page-bottom" => array("tag" => "integer"),
+                            "page-label" => array("tag" => "textWithoutLanguage"),
+                            "page-left" => array("tag" => "integer"),
+                            "page-right" => array("tag" => "integer"),
+                            "page-set" => array("tag" => "keyword"),
+                            "page-top" => array("tag" => "integer"),
+                            "penwidth" => array("tag" => "integer"),
+                            "position" => array("tag" => "keyword"),
+                            "ppi" => array("tag" => "integer"),
+                            "prettyprint" => array("tag","boolean"),
+                            "saturation" => array("tag" => "integer"),
+                            "scaling" => array("tag" => "integer"),
+                            "wrap" => array("tag","boolean"),
+                            
+                            );
         $this->job_tags = array_merge ($this->job_tags, $job_tags);
     }
     // }}}
 
+//
+// REQUEST BUILDING
+//
+
+    // {{{ _enumBuild ($tag,$value)
+    protected function _enumBuild ($tag,$value) {
+        
+        $value_built = parent::_enumBuild($tag,$value);
+       
+
+        switch ($tag) {
+           case "cpi":     
+                switch ($value) {
+                    case '10':
+                        $value_built = chr(10);
+                        break;
+                    case '12':
+                        $value_built = chr(12);
+                        break;
+                    case '17':
+                        $value_built = chr(17);
+                        break;
+                    default:
+                        $value_built = chr(10);
+                }
+            break;
+            case "lpi":
+                switch ($value) {
+                    case '6':
+                        $value_built = chr(6);
+                        break;
+                    case '8':
+                        $value_built = chr(8);
+                        break;
+                    default:
+                        $value_built = chr(6);
+                }
+            break;
+            }
+
+        $prepend = '';
+        while ((strlen($value_built) + strlen($prepend)) < 4)
+            $prepend .= chr(0);
+    return $prepend.$value_built;
+    }
+    // }}}
+    
 //
 // RESPONSE PARSING
 //
@@ -344,7 +547,7 @@ class CupsPrintIPP extends ExtendedPrintIPP {
         $value_parsed = 0;
         for ($i = strlen($value) ; $i > 0 ; $i --)
             $value_parsed += pow(256,($i - 1)) * ord($value[strlen($value) - $i]);
-        
+       
         $type[0] = $type[1] = $type[2] = $type[3] = $type[4] = $type[5] = '';
         $type[6] = $type[7] = $type[8] = $type[9] = $type[10] = '';
         $type[11] = $type[12] = $type[13] = $type[14] = $type[15] = '';
@@ -430,6 +633,26 @@ class CupsPrintIPP extends ExtendedPrintIPP {
     }
     // }}}
 
+    // {{{ _interpretEnum()
+    protected function _interpretEnum($attribute_name,$value) {
+       
+        $value_parsed = self::_interpretInteger($value);
+        
+        switch ($attribute_name) {
+            case 'cpi':
+            case 'lpi':
+                $value = $value_parsed;
+                break;
+            default:
+                $value = parent::_interpretEnum($attribute_name,$value);
+                break;
+            }
+        
+    
+    return $value;
+    }
+    // }}}
+    
 };
 
 /*
