@@ -42,10 +42,11 @@
 ***********************************************************/
 
 $host = "geekette.localdomain"; // set serve'rs host here
+$ssl = false; // enable ssl if true
 $printer_uri = "/printers/epson"; // set printer uri here
 $language = "fr_fr";
 $user = "test"; // valid user from lpadmin group
-$password = "test"; // his password
+$password = "0123Test"; // his password
 $document_uri = "http://localhost/";
 $debug_level = 1; // 1: silent; 3: very verbose
 
@@ -91,6 +92,7 @@ $ipp->setLog('/tmp/printipp','file',2); // logging verbose
 $ipp->setLog('/tmp/printipp','file',3); // logging very verbose
 
 $ipp->setHost("localhost");
+$ipp->ssl = $ssl;
 //$ipp->setHost("toto");// Resistance test
 $ipp->setHost($host); //Put your printer IP or hostname/fqdn here
 
@@ -111,13 +113,13 @@ $j = 0;
 $test = 1;
 
 /* printing a large file */
-
+/*
 echo "<br /><br /><br />TEST ".$test++."<br />";
 echo "OPERATION  ".$j++."<br />";
 $ipp->setAttribute("printer-resolution","1440x720dpi");
-#$ipp->setAttribute("job-sheets", array("confidential","secret"));
 $ipp->setAttribute("job-billing", "Thomas");
 $ipp->setAttribute("print-quality", "high");
+$ipp->setAttribute("scaling",100);
 //$ipp->setCopies(2);
 $ipp->setData('testfiles/photo.jpg');
 $ipp->setJobName('photo.jpg',true);
@@ -125,6 +127,8 @@ echo "Printing a large file: ". $ipp->PrintJob() . "<br />";
 printf('$ipp->status[0] = %s <br /><br />', $ipp->status[0]);
 $ipp->unsetAttribute("job-billing");
 $ipp->setJobName();
+$ipp->setAttribute("scaling","");
+
 
 /* getting printer's attributes */
 
@@ -137,7 +141,7 @@ echo "Printer up-time: ".date('Y-m-d H:i:s',$timestamp)."<br />";
 echo "Printer's attributes :<pre>\n"; print_r($ipp->printer_attributes); echo "</pre>";
 
 /* printing a string */
-
+/*
 echo "<br /><br /><br /> TEST ".$test ++."<br />";
 
 echo "OPERATION ". $j ++ ."<br />";
@@ -150,7 +154,7 @@ echo "Job Attributes:<pre>\n" ; print_r($ipp->job_attributes) ; echo "\n</pre>\n
 $first_job = $ipp->last_job;
 
 /* printing a text file */
-
+/*
 echo "<br /><br /><br /> TEST ".$test ++."<br />";
 
         // HINT: you _must_ supply a charset or set output as raw text
@@ -159,13 +163,15 @@ echo "OPERATION ". $j ++ ."<br />";
 $ipp->setCharset('us-ascii');
 $ipp->setMimeMediaType('text/plain');
 $ipp->setJobName("PHP Test: US ASCII file",true); // default is false: number is automagically appended
-
 $ipp->setData("./testfiles/test.txt");//Path to file.
+$ipp->setAttribute("job-sheets", array("confidential"));
 echo "US ASCII file Job status: ".$ipp->printJob("epson")."<br />";
-
+$ipp->setAttribute("job-sheets","");
+$ipp->setAttribute("cpi",""); //reset cpi
+$ipp->setAttribute("lpi","");
 
 /* printing a document by URI */
-
+/*
 echo "<br /><br /><br /> TEST ".$test ++."<br />";
 
 echo "OPERATION ". $j ++ ."<br />";
@@ -174,7 +180,7 @@ echo "Job Print URI status: ".$ipp->printUri($document_uri)."<br />";
 
 
 /* printing a text file in utf-8 */
-
+/*
 echo "<br /><br /><br /> TEST ".$test ++."<br />";
 
 echo "OPERATION ". $j ++ ."<br />";
@@ -192,7 +198,7 @@ echo "Printing testfile with UTF-8 characters: ".$ipp->printJob()."<br />";
 $ipp->unsetAttribute('orientation-requested');
 
 /* printing a gzipped file */
-
+/*
 echo "<br /><br /><br /> TEST ".$test ++."<br />";
 
 echo "OPERATION ". $j ++ ."<br />";
@@ -203,7 +209,7 @@ $ipp->unsetAttribute('compression');
 
 
 /* getting not-completed jobs */
-
+/*
 echo "<br /><br /><br /> TEST ".$test ++."<br />";
 
 echo "OPERATION ". $j ++ ."<br />";
@@ -214,7 +220,7 @@ echo "Job 0 state-reasons: ".$ipp->jobs_attributes->job_0->job_state_reasons->_v
 echo "<pre>";print_r($ipp->jobs_attributes); echo "</pre>";
 
 /* getting all jobs (subset of attributes) */
-
+/*
 echo "<br /><br /><br /> TEST ".$test ++."<br />";
 
 echo "OPERATION ". $j ++ ."<br />";
@@ -226,7 +232,7 @@ echo "<pre>";print_r($ipp->jobs_attributes); echo "</pre>";
 
 
 /* getting a job's attributes */
-
+/*
 echo "<br /><br /><br /> TEST ".$test ++."<br />";
 
 echo "OPERATION ". $j ++ ."<br />";
@@ -246,7 +252,7 @@ echo "Job-State-Reasons: $job_state_reasons<br />";
 echo "<pre>";print_r($ipp->job_attributes); echo "</pre>";
 
 /* setting job's attributes to new values */
-
+/*
 echo "<br /><br /><br /> TEST ".$test ++."<br />";
 
 echo "OPERATION ". $j ++ ."<br />";
@@ -268,7 +274,7 @@ echo "<pre>";print_r($ipp->job_attributes); echo "</pre>";
 
 
 /* printing selected pages from a document */
-
+/*
 echo "<br /><br /><br /> TEST ".$test ++."<br />";
 
 echo "OPERATION ". $j ++ ."<br />";
@@ -283,7 +289,7 @@ $ipp->unsetAttribute('media');
 $ipp->unsetAttribute('number-up');
 
 /* printing a postcript file */
-
+/*
 echo "<br /><br /><br /> TEST ".$test ++."<br />";
 
 echo "OPERATION ". $j ++ ."<br />";
@@ -293,7 +299,7 @@ echo "Printing Postscript Job status: ".$ipp->printJob("epson")."<br />";
 
 
 /* printing a png  file */
-
+/*
 echo "<br /><br /><br /> TEST ".$test ++."<br />";
 
 echo "OPERATION ". $j ++ ."<br />";
@@ -301,7 +307,7 @@ $ipp->setData("./testfiles/test.png");
 echo "Printing png Job status: ".$ipp->printJob("epson")."<br />";
 
 /* printing and cancelling job */
-
+/*
 echo "<br /><br /><br /> TEST ".$test ++."<br />";
 
 echo "Printing and Cancelling a job<br />";
@@ -314,7 +320,7 @@ echo "OPERATION ". $j ++ ."<br />";
 echo "Cancel status: ".$ipp->cancelJob($job)."<br />";
 
 /* printing strings, no form feed */
-
+/*
 echo "<br /><br /><br /> TEST ".$test ++."<br />";
 
 $ipp->setRawText();
@@ -351,7 +357,7 @@ $ipp->unsetRawText();
 
 
 /* printing a file to see if unsetRawText works */
-
+/*
 echo "<br /><br /><br /> TEST ".$test ++."<br />";
 
 echo "OPERATION ". $j ++ ."<br />";
@@ -360,7 +366,7 @@ echo "Job status (text file after strings): ".$ipp->printJob()."<br />";
 
 
 /* multiple document handling */
-
+/*
 echo "<br /><br /><br /> TEST ".$test ++."<br />";
 
 $ipp->setUserName("test");
@@ -390,7 +396,7 @@ echo "Sending document (must be refused): " . $ipp->sendDocument($job,$last=true
 
 
 /* try to validate a job with filetype printer server can't handle */
-
+/*
 echo "<br /><br /><br /> TEST ".$test ++."<br />";
 
 $ipp->setMimeMediaType("application/x-foobar");
@@ -398,6 +404,8 @@ $ipp->setMimeMediaType("application/x-foobar");
 echo "OPERATION ". $j ++ ."<br />";
 echo "Validate-Job for a document with file format 'application/x-foobar': ".$ipp->validateJob()."<br />";
 
+$ipp->setMimeMediaType();
+
 foreach ($ipp->attributes as $name => $attribute) {
     if ($attribute->_range == 'unsupported-attributes')
         printf('%s "%s": unsupported attribute<br />',$name,$attribute->_value0);
@@ -407,7 +415,7 @@ echo "Details:<pre>"; print_r($ipp->attributes) ; echo "</pre>";
 
 
 /* Printing then holding a job */
-
+/*
 echo "<br /><br /><br /> TEST ".$test ++."<br />";
 
 echo "OPERATION ". $j ++ ."<br />";
@@ -422,7 +430,7 @@ echo "Job State: ".$ipp->job_attributes->job_state->_value0."<br />";
 echo "Job State Reason: ".$ipp->job_attributes->job_state_reasons->_value0."<br />";
 
 /* releasing the job */
-
+/*
 echo "<br /><br /><br /> TEST ".$test ++."<br />";
 
 echo "OPERATION ". $j ++ ."<br />";
@@ -434,7 +442,7 @@ echo "Job State Reason: ".$ipp->job_attributes->job_state_reasons->_value0."<br
 
 
 /* restarting a job */
-
+/*
 echo "<br /><br /><br /> TEST ".$test ++."<br />";
 echo "OPERATION ". $j ++ ."<br />";
 echo "Restarting the job $first_job (if completed!): ".$ipp->restartJob($first_job)."<br />";
@@ -445,7 +453,7 @@ echo "Job State Reason: ".$ipp->job_attributes->job_state_reasons->_value0."<br
 
 
 /* purging jobs for a printer */
-
+/*
 echo "<br /><br /><br /> TEST ".$test ++."<br />";
 
 echo "OPERATION ". $j ++ ."<br />";
@@ -454,7 +462,7 @@ $ipp->setPrinterURI("ipp://localhost:631/printers/epson"); // Set printer URI he
 echo "Purge-Jobs for printer $printer_uri: ". $ipp->purgeJobs() ."<br />";
 
 /* purging jobs for all printers */
-
+/*
 echo "<br /><br /><br /> TEST ".$test ++."<br />";
 
 echo "OPERATION ". $j ++ ."<br />";
@@ -463,7 +471,7 @@ echo "Purge-Jobs (all printers): ". $ipp->purgeJobs() ."<br />";
 
 
 /* pausing printer */
-
+/*
 echo "<br /><br /><br /> TEST ".$test ++."<br />";
 
 echo "OPERATION ". $j ++ ."<br />";
@@ -475,7 +483,7 @@ echo "Getting printer's attributes: ".$ipp->getPrinterAttributes()."<br />";
 echo "Printer State: ".$ipp->printer_attributes->printer_state->_value0."<br />";
 
 /* Resuming printer */
-
+/*
 echo "<br /><br /><br /> TEST ".$test ++."<br />";
 
 echo "OPERATION ". $j ++ ."<br />";
@@ -486,8 +494,43 @@ echo "Getting printer's attributes: ".$ipp->getPrinterAttributes()."<br />";
 echo "Printer State: ".$ipp->printer_attributes->printer_state->_value0."<br />";
 
 
-/* getting only default printer's uri (CUPS extention) */
+/* rejecting jobs (CUPS specific)*/
 
+echo "<br /><br /><br />TEST ".$test++."<br />";
+echo "OPERATION  ".$j++."<br />";
+echo "Rejecting jobs for printer $printer_uri (CUPS operation): ".$ipp->cupsRejectJobs($printer_uri,$printer_state_message="Printer stopped for maintainance")."<br />";
+
+// try to print //
+
+echo "OPERATION ". $j ++ ."<br />";
+$ipp->setCharset('us-ascii');
+$ipp->setMimeMediaType('text/plain');
+$ipp->setJobName("PHP Test: US ASCII file",true); // default is false: number is automagically appended
+//$ipp->setAttribute("job-sheets", array("confidential","secret"));
+$ipp->setAttribute("cpi",17); // 10,12 or 17. default to 10 //cpi and lpi attributes are CUPS specific
+$ipp->setAttribute("lpi",8); // 6 or 8, default: 6
+$ipp->setData("./testfiles/test.txt");//Path to file.
+echo "US ASCII file Job status: ".$ipp->printJob("epson")."<br />";
+$ipp->setAttribute("cpi",""); //reset cpi
+$ipp->setAttribute("lpi","");
+
+echo "OPERATION ". $j ++ ."<br />";
+$ipp->getPrinterAttributes();
+printf("Printer state: %s (%s)<br />",$ipp->printer_attributes->printer_state->_value0,
+                                      $ipp->printer_attributes->printer_state_message->_value0);
+// Accepting Jobs (CUPS specfic) //
+
+echo "OPERATION  ".$j++."<br />";
+echo "Accepting jobs for printer $printer_uri (CUPS operation): ".$ipp->cupsAcceptJobs($printer_uri)."<br />";
+
+/* printing the text file */
+/*
+echo "OPERATION  ".$j++."<br />";
+echo "US ASCII file Job status: ".$ipp->printJob("epson")."<br />";
+
+
+/* getting only default printer's uri (CUPS extention) */
+/*
 echo "<br /><br /><br />TEST ".$test++."<br />";
 echo "OPERATION ".$j ++."<br />";
 
@@ -498,7 +541,7 @@ print_r($ipp->printer_attributes); echo "</pre>";
 
 
 /* getting default printer attributes (CUPS extension) */
-
+/*
 echo "<br /><br /><br />TEST ".$test++."<br />";
 echo "OPERATION ".$j ++."<br />";
 echo "Getting default printer attributes [CUPS specific]<br /><pre>\n";
@@ -527,7 +570,7 @@ echo "<br /><br /><br />\n";
 
 
 /* getting printers (vendor extention) (currently CUPS only)*/
-
+/*
 echo "<br /><br /><br /> TEST ".$test ++."<br />";
 
 echo "OPERATION ".$j++."<br />";
@@ -580,7 +623,7 @@ $ipp->resetError("request_body_malformed");
 
 
 /**/
-/*
+
 echo "END OF OPERATIONS <br /><br /><br />";
 
 /* get informations about jobs and status */
