@@ -1,6 +1,6 @@
 <?php
 /* vim: set expandtab tabstop=4 shiftwidth=4 foldmethod=marker: */
- /* @(#) $Header: /sources/phpprintipp/phpprintipp/http_class.php,v 1.2 2006/01/10 19:15:38 harding Exp $
+ /* @(#) $Header: /sources/phpprintipp/phpprintipp/http_class.php,v 1.3 2006/01/19 17:54:23 harding Exp $
  *
  *
  * Version: 0.2 -- E X P E R I M E N T A L
@@ -35,11 +35,12 @@
     It is a replacement for http://www.phpclasses.org/browse/package/3.html
     in versions post-
     
-    It can perform Basic authentication.
-    It works only in clear mode
+    It can perform Basic and Digest authentication.
+    It was tested only in clear mode
     
     References needed to debug / add functionnalities:
         - RFC 2616
+        - RFC 2617
 */
 /*
     TODO: beta tests on servers other than loopback one
@@ -76,6 +77,8 @@ class http_class {
     private $bodystream = array();
     private $last_limit;
     private $connected;
+    private $nc = 1;
+    private $user_agent = "PrintIPP http backend V0.3";
     // }}}
             
     // {{{ constructor
@@ -98,7 +101,7 @@ class http_class {
         $arguments["URL"] = $this->arguments["URL"] = $url;
         $arguments["RequestMethod"] = $this->arguments["RequestMethod"] = "POST";
         
-        $this->headers["User-agent"] = "PrintIPP Tiny version 0.1";
+        $this->headers["User-agent"] = $this->user_agent;
         $this->headers["Content-Type"] = "application/octet-stream";
     
     }
@@ -167,14 +170,18 @@ class http_class {
             return("SendRequest: need authentication but no mechanism provided");
 
          $authtype = split(' ',$this->reply_headers["www-authenticate"]);
-         
-         switch ($authtype[0]) {
+         $authtype = strtolower($authtype[0]);
+
+         switch ($authtype) {
             case 'basic':
                 $pass = base64_encode($this->user.":".$this->password);
                 $arguments["Headers"]["Authorization"] = "Basic ".$pass;
                 break;
+            case 'digest':
+                $arguments["Headers"]["Authorization"] = self::_BuildDigest();
+                break;
             default:
-                return sprintf(_("SendRequest: need '%s' authentication mechanism, but have not, sorry"),$authtype[0]);
+                return sprintf(_("http_class: need '%s' authentication mechanism, but have not, sorry"),$authtype[0]);
          }
         
          self::Close();
@@ -213,7 +220,7 @@ class http_class {
 *
 **********************/
 
-    // {{{ StreamRequest ($arguments)
+    // {{{ _StreamRequest ($arguments)
     private function _StreamRequest ($arguments) {
         
         $this->status = "";
@@ -352,7 +359,7 @@ class http_class {
     }
     // }}}
     
-    // {{{ ReadReply ()
+    // {{{ _ReadReply ()
     private function _ReadReply () {
       
         $this->reply_headers = array();
@@ -376,7 +383,12 @@ class http_class {
         $this->status = strtolower($headers[0]);
       
         foreach($headers as $header) {
-            $header = preg_split("#: #",strtolower($header));
+            if (!preg_match('#www-authenticate: #i',$header))
+                $header = strtolower($header);
+            
+            $header = preg_split("#: #",$header);
+            $header[0] =  strtolower($header[0]);
+
                 $this->reply_headers["{$header[0]}"] = array_key_exists(1,$header) ? $header[1] : "";
             }
             unset ($this->reply_headers['']);
@@ -421,6 +433,99 @@ class http_class {
     return true;
     }
     // }}}
+
+    // {{{ _BuildDigest ()
+    private function _BuildDigest () {
+        
+        $auth = $this->reply_headers["www-authenticate"];
+        
+        list($head, $auth) = split(" ",$auth,2);
+
+        $auth=split(", ",$auth);
+        foreach ($auth as $sheme) {
+            list($sheme,$value) = split('=',$sheme);
+            $fields[$sheme] = trim(trim($value),'"');
+        }
+
+        $nc = sprintf('%x',$this->nc);
+        $prepend = "";
+        while ((strlen($nc) + strlen($prepend)) < 8)
+            $prepend .= "0";
+        $nc=$prepend.$nc;
+        
+        $cnonce = "printipp";
+        
+        $username = $this->user;
+        $password = $this->password;
+    
+        $A1 = $username.":".$fields["realm"].":".$password;
+        
+        if (array_key_exists("algorithm",$fields)) {
+            $algorithm = strtolower($fields["algorithm"]);
+            switch ($algorithm) {
+                case "md5":
+                    break;
+                case "md5-sess":
+                    $A1 = $username.":".$fields["realm"].":".$password.":".$fields['nonce'].":".$cnonce;
+                    break;
+                case "token":
+                    trigger_error("http_class: digest Authorization: algorithm 'token' not implemented", E_USER_WARNING);
+                    return false;
+                    break;
+                }
+
+            }
+        
+        $A2 = "POST:".$this->arguments["RequestURI"];
+
+        
+        if (array_key_exists("qop",$fields)) {
+            $qop = strtolower($fields["qop"]);
+            $qop = split(" ",$qop);
+            if (in_array("auth",$qop))
+                $qop = "auth";
+            else {
+                trigger_error("http_class: digest Authorization: qop others than 'auth' not implemented", E_USER_WARNING);
+                return false;
+                }
+            }
+
+            
+        $response = md5(md5($A1).":". $fields["nonce"].":" .md5($A2));
+        
+        if (isset($qop) && ($qop == "auth"))
+        $response = md5(md5($A1).":".$fields["nonce"].":".$nc.":".$cnonce.":".$qop.":".$A2);
+
+        
+        $auth_scheme = sprintf('Digest username="%s", realm="%s", nonce="%s", uri="%s", response="%s"',
+                                $username,
+                                $fields["realm"],
+                                $fields['nonce'],
+                                $this->arguments["RequestURI"],
+                                $response
+                                );
+        
+        if (isset($algorithm))
+            $auth_scheme .= sprintf(', algorithm="%s"',$algorithm);
+
+        if (isset($qop))
+            $auth_scheme .= sprintf(', cnonce="%s"',$cnonce);
+        
+        if(array_key_exists("opaque",$fields))
+            $auth_scheme .= sprintf(', opaque="%s"',$fields['opaque']);
+      
+        if (isset($qop))
+            $auth_scheme .= sprintf(', qop="%s"',$qop);
+      
+        $auth_scheme .= sprintf(', nc=%s',$nc);
+      
+        $this->nc++;
+        
+        //echo $auth_scheme;
+    return $auth_scheme;
+    }
+    // }}}
+
 };
 
 
